@@ -109,7 +109,7 @@ class Exceptions:
 
 class GlueDataBrewClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html)
     """
 
@@ -127,7 +127,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes one or more versions of a recipe at a time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#batch_delete_recipe_version)
         """
 
@@ -135,7 +135,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#can_paginate)
         """
 
@@ -144,15 +144,15 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         Input: "InputTypeDef",
-        Format: InputFormatType = None,
-        FormatOptions: "FormatOptionsTypeDef" = None,
-        PathOptions: "PathOptionsTypeDef" = None,
-        Tags: Mapping[str, str] = None
+        Format: InputFormatType = ...,
+        FormatOptions: "FormatOptionsTypeDef" = ...,
+        PathOptions: "PathOptionsTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Creates a new DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_dataset)
         """
 
@@ -163,20 +163,20 @@ class GlueDataBrewClient(BaseClient):
         Name: str,
         OutputLocation: "S3LocationTypeDef",
         RoleArn: str,
-        EncryptionKeyArn: str = None,
-        EncryptionMode: EncryptionModeType = None,
-        LogSubscription: LogSubscriptionType = None,
-        MaxCapacity: int = None,
-        MaxRetries: int = None,
-        Configuration: "ProfileConfigurationTypeDef" = None,
-        Tags: Mapping[str, str] = None,
-        Timeout: int = None,
-        JobSample: "JobSampleTypeDef" = None
+        EncryptionKeyArn: str = ...,
+        EncryptionMode: EncryptionModeType = ...,
+        LogSubscription: LogSubscriptionType = ...,
+        MaxCapacity: int = ...,
+        MaxRetries: int = ...,
+        Configuration: "ProfileConfigurationTypeDef" = ...,
+        Tags: Mapping[str, str] = ...,
+        Timeout: int = ...,
+        JobSample: "JobSampleTypeDef" = ...
     ) -> CreateProfileJobResponseTypeDef:
         """
         Creates a new job to analyze a dataset and create its data profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_profile_job)
         """
 
@@ -187,13 +187,13 @@ class GlueDataBrewClient(BaseClient):
         Name: str,
         RecipeName: str,
         RoleArn: str,
-        Sample: "SampleTypeDef" = None,
-        Tags: Mapping[str, str] = None
+        Sample: "SampleTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateProjectResponseTypeDef:
         """
         Creates a new DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_project)
         """
 
@@ -202,13 +202,13 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         Steps: Sequence["RecipeStepTypeDef"],
-        Description: str = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateRecipeResponseTypeDef:
         """
         Creates a new DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe)
         """
 
@@ -217,19 +217,19 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         RoleArn: str,
-        DatasetName: str = None,
-        EncryptionKeyArn: str = None,
-        EncryptionMode: EncryptionModeType = None,
-        LogSubscription: LogSubscriptionType = None,
-        MaxCapacity: int = None,
-        MaxRetries: int = None,
-        Outputs: Sequence["OutputTypeDef"] = None,
-        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = None,
-        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = None,
-        ProjectName: str = None,
-        RecipeReference: "RecipeReferenceTypeDef" = None,
-        Tags: Mapping[str, str] = None,
-        Timeout: int = None
+        DatasetName: str = ...,
+        EncryptionKeyArn: str = ...,
+        EncryptionMode: EncryptionModeType = ...,
+        LogSubscription: LogSubscriptionType = ...,
+        MaxCapacity: int = ...,
+        MaxRetries: int = ...,
+        Outputs: Sequence["OutputTypeDef"] = ...,
+        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = ...,
+        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = ...,
+        ProjectName: str = ...,
+        RecipeReference: "RecipeReferenceTypeDef" = ...,
+        Tags: Mapping[str, str] = ...,
+        Timeout: int = ...
     ) -> CreateRecipeJobResponseTypeDef:
         """
         Creates a new job to transform input data, using steps defined in an existing
@@ -237,7 +237,7 @@ class GlueDataBrewClient(BaseClient):
         <https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob>`_
         **Request Syntax** response = client.create_recipe_job( DatasetName...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe_job)
         """
 
@@ -246,13 +246,13 @@ class GlueDataBrewClient(BaseClient):
         *,
         CronExpression: str,
         Name: str,
-        JobNames: Sequence[str] = None,
-        Tags: Mapping[str, str] = None
+        JobNames: Sequence[str] = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateScheduleResponseTypeDef:
         """
         Creates a new schedule for one or more DataBrew jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_schedule)
         """
 
@@ -260,7 +260,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a dataset from DataBrew.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_dataset)
         """
 
@@ -268,7 +268,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_job)
         """
 
@@ -276,7 +276,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_project)
         """
 
@@ -286,7 +286,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a single version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_recipe_version)
         """
 
@@ -294,7 +294,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_schedule)
         """
 
@@ -302,7 +302,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_dataset)
         """
 
@@ -310,7 +310,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job)
         """
 
@@ -318,7 +318,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Represents one run of a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job_run)
         """
 
@@ -326,18 +326,18 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_project)
         """
 
     def describe_recipe(
-        self, *, Name: str, RecipeVersion: str = None
+        self, *, Name: str, RecipeVersion: str = ...
     ) -> DescribeRecipeResponseTypeDef:
         """
         Returns the definition of a specific DataBrew recipe corresponding to a
         particular version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_recipe)
         """
 
@@ -345,97 +345,97 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_schedule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#generate_presigned_url)
         """
 
     def list_datasets(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListDatasetsResponseTypeDef:
         """
         Lists all of the DataBrew datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_datasets)
         """
 
     def list_job_runs(
-        self, *, Name: str, MaxResults: int = None, NextToken: str = None
+        self, *, Name: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListJobRunsResponseTypeDef:
         """
         Lists all of the previous runs of a particular DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_job_runs)
         """
 
     def list_jobs(
         self,
         *,
-        DatasetName: str = None,
-        MaxResults: int = None,
-        NextToken: str = None,
-        ProjectName: str = None
+        DatasetName: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        ProjectName: str = ...
     ) -> ListJobsResponseTypeDef:
         """
         Lists all of the DataBrew jobs that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_jobs)
         """
 
     def list_projects(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListProjectsResponseTypeDef:
         """
         Lists all of the DataBrew projects that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_projects)
         """
 
     def list_recipe_versions(
-        self, *, Name: str, MaxResults: int = None, NextToken: str = None
+        self, *, Name: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListRecipeVersionsResponseTypeDef:
         """
         Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipe_versions)
         """
 
     def list_recipes(
-        self, *, MaxResults: int = None, NextToken: str = None, RecipeVersion: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ..., RecipeVersion: str = ...
     ) -> ListRecipesResponseTypeDef:
         """
         Lists all of the DataBrew recipes that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipes)
         """
 
     def list_schedules(
-        self, *, JobName: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, JobName: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> ListSchedulesResponseTypeDef:
         """
         Lists the DataBrew schedules that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_schedules)
         """
 
@@ -443,15 +443,15 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all the tags for a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_tags_for_resource)
         """
 
-    def publish_recipe(self, *, Name: str, Description: str = None) -> PublishRecipeResponseTypeDef:
+    def publish_recipe(self, *, Name: str, Description: str = ...) -> PublishRecipeResponseTypeDef:
         """
         Publishes a new version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#publish_recipe)
         """
 
@@ -459,17 +459,17 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        Preview: bool = None,
-        RecipeStep: "RecipeStepTypeDef" = None,
-        StepIndex: int = None,
-        ClientSessionId: str = None,
-        ViewFrame: "ViewFrameTypeDef" = None
+        Preview: bool = ...,
+        RecipeStep: "RecipeStepTypeDef" = ...,
+        StepIndex: int = ...,
+        ClientSessionId: str = ...,
+        ViewFrame: "ViewFrameTypeDef" = ...
     ) -> SendProjectSessionActionResponseTypeDef:
         """
         Performs a recipe step within an interactive DataBrew session that's currently
         open.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#send_project_session_action)
         """
 
@@ -477,18 +477,18 @@ class GlueDataBrewClient(BaseClient):
         """
         Runs a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_job_run)
         """
 
     def start_project_session(
-        self, *, Name: str, AssumeControl: bool = None
+        self, *, Name: str, AssumeControl: bool = ...
     ) -> StartProjectSessionResponseTypeDef:
         """
         Creates an interactive session, enabling you to manipulate data in a DataBrew
         project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_project_session)
         """
 
@@ -496,7 +496,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Stops a particular run of a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#stop_job_run)
         """
 
@@ -505,7 +505,7 @@ class GlueDataBrewClient(BaseClient):
         Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe,
         job, or schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#tag_resource)
         """
 
@@ -513,7 +513,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Removes metadata tags from a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#untag_resource)
         """
 
@@ -522,14 +522,14 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         Input: "InputTypeDef",
-        Format: InputFormatType = None,
-        FormatOptions: "FormatOptionsTypeDef" = None,
-        PathOptions: "PathOptionsTypeDef" = None
+        Format: InputFormatType = ...,
+        FormatOptions: "FormatOptionsTypeDef" = ...,
+        PathOptions: "PathOptionsTypeDef" = ...
     ) -> UpdateDatasetResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_dataset)
         """
 
@@ -539,39 +539,39 @@ class GlueDataBrewClient(BaseClient):
         Name: str,
         OutputLocation: "S3LocationTypeDef",
         RoleArn: str,
-        Configuration: "ProfileConfigurationTypeDef" = None,
-        EncryptionKeyArn: str = None,
-        EncryptionMode: EncryptionModeType = None,
-        LogSubscription: LogSubscriptionType = None,
-        MaxCapacity: int = None,
-        MaxRetries: int = None,
-        Timeout: int = None,
-        JobSample: "JobSampleTypeDef" = None
+        Configuration: "ProfileConfigurationTypeDef" = ...,
+        EncryptionKeyArn: str = ...,
+        EncryptionMode: EncryptionModeType = ...,
+        LogSubscription: LogSubscriptionType = ...,
+        MaxCapacity: int = ...,
+        MaxRetries: int = ...,
+        Timeout: int = ...,
+        JobSample: "JobSampleTypeDef" = ...
     ) -> UpdateProfileJobResponseTypeDef:
         """
         Modifies the definition of an existing profile job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_profile_job)
         """
 
     def update_project(
-        self, *, RoleArn: str, Name: str, Sample: "SampleTypeDef" = None
+        self, *, RoleArn: str, Name: str, Sample: "SampleTypeDef" = ...
     ) -> UpdateProjectResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_project)
         """
 
     def update_recipe(
-        self, *, Name: str, Description: str = None, Steps: Sequence["RecipeStepTypeDef"] = None
+        self, *, Name: str, Description: str = ..., Steps: Sequence["RecipeStepTypeDef"] = ...
     ) -> UpdateRecipeResponseTypeDef:
         """
         Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe)
         """
 
@@ -580,58 +580,58 @@ class GlueDataBrewClient(BaseClient):
         *,
         Name: str,
         RoleArn: str,
-        EncryptionKeyArn: str = None,
-        EncryptionMode: EncryptionModeType = None,
-        LogSubscription: LogSubscriptionType = None,
-        MaxCapacity: int = None,
-        MaxRetries: int = None,
-        Outputs: Sequence["OutputTypeDef"] = None,
-        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = None,
-        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = None,
-        Timeout: int = None
+        EncryptionKeyArn: str = ...,
+        EncryptionMode: EncryptionModeType = ...,
+        LogSubscription: LogSubscriptionType = ...,
+        MaxCapacity: int = ...,
+        MaxRetries: int = ...,
+        Outputs: Sequence["OutputTypeDef"] = ...,
+        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = ...,
+        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = ...,
+        Timeout: int = ...
     ) -> UpdateRecipeJobResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew recipe job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe_job)
         """
 
     def update_schedule(
-        self, *, CronExpression: str, Name: str, JobNames: Sequence[str] = None
+        self, *, CronExpression: str, Name: str, JobNames: Sequence[str] = ...
     ) -> UpdateScheduleResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_schedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
         """
 
@@ -640,20 +640,20 @@ class GlueDataBrewClient(BaseClient):
         self, operation_name: Literal["list_recipe_versions"]
     ) -> ListRecipeVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
         """
